{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Julia.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/julia.xml and 'make bootstrap'.
module Skylighting.Syntax.Julia (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Julia.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjulia.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t1-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t1-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBacktick-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBacktick-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKBlock-Backtick-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKBlock-Backtick-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX```\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBlock-Regex-Square-Bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBlock-Regex-Square-Bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlock-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlock-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDefault-Regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDefault-Regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH(?\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX()|\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT?+*.\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERaw-Block-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERaw-Block-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRaw-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRaw-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n(\\\\\\\\)*\\\\\"\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f(\\\\\\\\)+(?=\")\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Regex-Block-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Regex-Block-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\"{3}[imsx]{1,4}\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[^\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBlock-Regex-Square-Bracket\NUL[\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBBlock-Regex-Square-Bracket\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDefault-Regex\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlock-String\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Regex-Square-Bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Regex-Square-Bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegex-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegex-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\"[imsx]{1,4}\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[^\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Regex-Square-Bracket\NUL[\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Regex-Square-Bracket\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDefault-Regex\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\a\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_adjoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_adjoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX'+\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_normal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_normal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NULE\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afinally\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#BEGIN\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rregion_marker\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#END\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rregion_marker\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\\b(abstract|primitive)\\s+type\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\bmutable\\s+struct\\b\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babstract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbaremodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbitstype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQccall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timportall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttypealias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\233\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vASCIIString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAbstractArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AbstractArrayStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAbstractChannel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAbstractChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAbstractDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAbstractDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAbstractFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AbstractIrrational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAbstractLock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAbstractLogger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAbstractMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAbstractRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAbstractSet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAbstractString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AbstractUnitRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAbstractVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAnonymous\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rArgumentError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nArrayStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssertionError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssociative\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAsyncCondition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAtomic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBase64DecodePipe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBase64EncodePipe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBigFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBigInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBitArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBitMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBitSet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBitVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoundsError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBroadcastStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nByteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CapturedException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCartesianIndex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECartesianIndices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aChannel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQClong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tClonglong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQColon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComplex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nComplex128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComplex64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nComplexF16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nComplexF32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nComplexF64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vComplexPair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CompositeException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCompoundPeriod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCondition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rConsoleLogger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCptrdiff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCsize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCssize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCuchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCuintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCulong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCulonglong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCushort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCwchar_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCwstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDateFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDateTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DefaultArrayStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDenseArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDenseMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDenseVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DimensionMismatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDims\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDivideError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDomainError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEOFError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEnum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEnvDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOErrorException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ExponentialBackOff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFloat16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFloat32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFloat64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIOBuffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIOContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIOStream\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTIPv4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTIPv6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIdDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImmutableDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIndexCartesian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIndexLinear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIndexStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInexactError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tInitError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKInt128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInt16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInt32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTInt8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIntSet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2InterruptException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKInvalidStateException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIrrational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIteratorEltype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bKeyError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLinRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLinearIndices\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLoadError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLogLevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMersenneTwister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMethodError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMissing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMissingException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMutex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNTuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNamedTuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNullLogger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fObjectIdDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOneTo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOrdinalRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutOfMemoryError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOverflowError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nParseError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPartialQuickSort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPeriod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PermutedDimsArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNProcessFailedException\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRandomDevice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRange1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRawFD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ReadOnlyMemoryError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTReal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RecursiveSpinLock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rReentrantLock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRegexMatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRoundingMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSemaphore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSharedArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSimpleLogger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISparseMatrixCSC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSparseVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSpinLock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStackFrame\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StackOverflowError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStackTrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStateful\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStepRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStepRangeLen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStridedArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStridedMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIStridedVecOrMat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStridedVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStringIndexError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SubstitutionString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSystemError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTCPSocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTextDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTimeType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTmStruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTypeError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUDPSocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTUInt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUInt128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUInt16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUInt32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUInt64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUInt8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nUTF8String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUTInstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUndefInitializer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1UndefKeywordError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUndefRefError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUndefVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUnion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUnionAll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUnitRange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUnsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVararg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVecOrMat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVersionNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWeakKeyDict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWeakRef\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\SYN\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTARCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTARGS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAbstractVecOrMat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBINDIR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCPU_THREADS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKC_NULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEPOT_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDenseVecOrMat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nENDIAN_BOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXENV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXInf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInf16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInf32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQInf64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInsertionSort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKKERNEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLOAD_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMACHINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMS_ASYNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMS_INVALIDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMS_SYNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMergeSort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNaN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNaN16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNaN32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNaN64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPROGRAM_FILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tQuickSort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRoundDown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRoundFromZero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRoundNearest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RoundNearestTiesAway\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2RoundNearestTiesUp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRoundToZero\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRoundUp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStridedArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStridedMatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIStridedVecOrMat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStridedVector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVecOrMat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tWORD_SIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKappend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acatalan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neulergamma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgolden\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amissing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstderr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\ENQ\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBroadcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCoreLogging\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDocs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIterators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLibc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathConstants\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMeta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSharedArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSockets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSparseArrays\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStackTraces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aThreads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUnicode\NAK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#=\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rblock-comment\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t1-comment\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlock-String\NUL\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTr\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Regex-Block-String\SOHr\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegex-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTb\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlock-String\SOHb\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\SOHv\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKraw\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERaw-Block-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTraw\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRaw-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdoc\"\"\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlock-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdoc\"\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX```\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKBlock-Backtick-String\NUL`\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBacktick-String\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX...\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH::\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT>>>=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>>=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<<=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX>>>\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>>\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<<\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH==\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH!=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.*\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.^\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH./\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.'\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH|=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH$=\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE[a-zA-Z]\\w*(?=')\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_adjoint\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULa([0-9]([0-9_]*[0-9])?(\\.[0-9]([0-9_]*[0-9])?)?|\\.[0-9]([0-9_]*[0-9])?)([eEfF][+-]?\\d+)?(im)?(?=')\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_adjoint\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[\\)\\]}](?=')\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_adjoint\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\.'(?=')\SOH\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_adjoint\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC'[^']*(''[^']*)*'(?=[^']|$)\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE'[^']*(''[^']*)*\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r@[a-zA-Z_]\\w*\SOH\ETB\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\b[A-Za-z_]\\w*(?=\\!?\\()\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\144\&0x([0-9a-fA-F]([0-9a-fA-F_]*[0-9a-fA-F])?\\.?|([0-9a-fA-F]([0-9a-fA-F_]*[0-9a-fA-F])?)?\\.[0-9a-fA-F]([0-9a-fA-F_]*[0-9a-fA-F])?)[pP][+-]?\\d+(im)?\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-0x[0-9a-fA-F]([0-9a-fA-F_]*[0-9a-fA-F])?(im)?\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC0o[0-7]([0-7_]*[0-7])?(im)?\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN0b[01]([01_]*[01])?(im)?\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\([0-9]([0-9_]*[0-9])?(\\.[0-9]([0-9_]*[0-9])?)?|\\.[0-9]([0-9_]*[0-9])?)([eEfF][+-]?\\d+)?(im)?\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK()[]{}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2*+-/\\&|<>~$!^=,;:@\DC4\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rblock-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rblock-comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rregion_marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rregion_marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t1-comment\EM\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.jl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_normal"
